/*
 * core.c
 *
 *  Created on: 11.02.2012
 *      Author: spiritus
 */
#include <avr/io.h>
#include <avr/interrupt.h>
#include <util/delay.h>
#include <avr/sleep.h>

volatile unsigned int WorkMeltingDelay;

#define LINETIME 1			//line show time in ms
#define WORKTIME 30			//working time in seconds


ISR(INT0_vect)
{


}

ISR (TIMER1_COMPA_vect)		//1 per sec
{
	TCNT1H=0x00;
	TCNT1L=0x00;
	if (WorkMeltingDelay > 0) WorkMeltingDelay--;

}

void RegistersInit (void)
{

		// Input/Output Ports initialization
		// Port B initialization
		// Func7=In Func6=In Func5=In Func4=In Func3=In Func2=In Func1=In Func0=In
		// State7=T State6=T State5=T State4=T State3=T State2=T State1=T State0=T
		PORTB=0x00;
		DDRB=0x00;

		// Port C initialization
		// Func6=In Func5=In Func4=In Func3=In Func2=In Func1=In Func0=In
		// State6=T State5=T State4=T State3=T State2=T State1=T State0=T
		PORTC=0x00;
		DDRC=0x00;

		// Port D initialization
		// Func7=In Func6=In Func5=In Func4=In Func3=In Func2=In Func1=In Func0=In
		// State7=T State6=T State5=T State4=T State3=T State2=P State1=T State0=T
		PORTD=0x04;
		DDRD=0x00;

		// Timer/Counter 0 initialization
		// Clock source: System Clock
		// Clock value: Timer 0 Stopped
		TCCR0=0x00;
		TCNT0=0x00;

		// Timer/Counter 1 initialization
		// Clock source: System Clock
		// Clock value: 0,977 kHz
		// Mode: Normal top=FFFFh
		// OC1A output: Discon.
		// OC1B output: Discon.
		// Noise Canceler: Off
		// Input Capture on Falling Edge
		// Timer 1 Overflow Interrupt: Off
		// Input Capture Interrupt: Off
		// Compare A Match Interrupt: On
		// Compare B Match Interrupt: Off
		TCCR1A=0x00;
		TCCR1B=0x05;
		TCNT1H=0x00;
		TCNT1L=0x00;
		ICR1H=0x00;
		ICR1L=0x00;
		OCR1AH=0x03;
		OCR1AL=0xD1;
		OCR1BH=0x00;
		OCR1BL=0x00;

		// Timer/Counter 2 initialization
		// Clock source: System Clock
		// Clock value: Timer 2 Stopped
		// Mode: Normal top=FFh
		// OC2 output: Disconnected
		ASSR=0x00;
		TCCR2=0x00;
		TCNT2=0x00;
		OCR2=0x00;

		// External Interrupt(s) initialization
		// INT0: On
		// INT0 Mode: Falling Edge
		// INT1: Off
		GICR|=0x40;
		MCUCR=0x02;
		GIFR=0x40;

		// Timer(s)/Counter(s) Interrupt(s) initialization
		TIMSK=0x10;

		// Analog Comparator initialization
		// Analog Comparator: Off
		// Analog Comparator Input Capture by Timer/Counter 1: Off
		ACSR=0x80;
		SFIOR=0x00;


		sei();
}


void ShowLine (unsigned char line)
{
	DDRD |= (_BV(6) | _BV(7));
	DDRB = 0xFF;
	PORTD &= ~(_BV(6) | _BV(7));
	PORTB = 0x00;

	if(line & _BV(0)) PORTD |= _BV(6);
	if(line & _BV(1)) PORTD |= _BV(7);
	if(line & _BV(2)) PORTB |= _BV(0);
	if(line & _BV(3)) PORTB |= _BV(1);
	if(line & _BV(4)) PORTB |= _BV(2);
	if(line & _BV(5)) PORTB |= _BV(3);
	if(line & _BV(6)) PORTB |= _BV(4);
	if(line & _BV(7)) PORTB |= _BV(5);

	_delay_ms(LINETIME);

}

int main(void)
{
	RegistersInit();

	while (1)
	{

		WorkMeltingDelay = WORKTIME;

		while (WorkMeltingDelay != 0)
		{


			ShowLine(0b00000000);
			ShowLine(0b00000000);
			ShowLine(0b00000000);
			ShowLine(0b00110000);
			ShowLine(0b01111000);
			ShowLine(0b11111100);
			ShowLine(0b01111110);
			ShowLine(0b00111111);
			ShowLine(0b01111110);
			ShowLine(0b11111100);
			ShowLine(0b01111000);
			ShowLine(0b00110000);
			ShowLine(0b00000000);
			ShowLine(0b00000000);
			ShowLine(0b00000000);
/*
			ShowLine(0b11000011);
			ShowLine(0b11000011);
			ShowLine(0b11010011);
			ShowLine(0b11010011);
			ShowLine(0b11111111);
			ShowLine(0b11111111);
			ShowLine(0b00000000);
			ShowLine(0b11111100);
			ShowLine(0b11111110);
			ShowLine(0b00000111);
			ShowLine(0b00000011);
			ShowLine(0b00000111);
			ShowLine(0b11111110);
			ShowLine(0b11111100);
			ShowLine(0b00000000);
			ShowLine(0b00111100);
			ShowLine(0b01111110);
			ShowLine(0b11100111);
			ShowLine(0b11000011);
			ShowLine(0b11100111);
			ShowLine(0b01111110);
			ShowLine(0b00111100);
			ShowLine(0b00000000);
			ShowLine(0b00000011);
			ShowLine(0b00000011);
			ShowLine(0b00000011);
			ShowLine(0b00000011);
			ShowLine(0b11111111);
			ShowLine(0b11111111);
			ShowLine(0b00000000);
			ShowLine(0b00000000);
			ShowLine(0b00000000);*/





		};

				set_sleep_mode(SLEEP_MODE_PWR_DOWN);
				sleep_enable();
				DDRD &= ~(_BV(6) | _BV(7));
				DDRB = 0x00;
				PORTD &= ~(_BV(6) | _BV(7));
				PORTB = 0x00;
				sei();




				sleep_cpu(); //until reset, we haven`t got a crystall on board((




	};

	return 0;
}
